<?php
/*
Plugin Name: Force User Field Registration
Plugin URI: http://www.andrewferguson.net/wordpress-plugins/force-user-field-registration/
Plugin Description: Forces new users to register additional fields.
Version: 0.6
Author: Andrew Ferguson
Author URI: http://www.andrewferguson.net/

Force User Field Registration - Forces new users to register additional fields
Copyright (c) 2007-2008 Andrew Ferguson
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/


add_action('register_form', 'fergcorp_forceRegistrationField_addFields');
add_action('register_post', 'fergcorp_forceRegistrationField_checkFields', 10, 3);
add_action('user_register', 'fergcorp_forceRegistrationField_updateFields', 10, 1);
add_action('admin_menu', 'fergcorp_forceRegistrationField_optionsPage');

$fergcorp_forceRegistrationField_knownFields = array(
	"first_name"	=> "First Name",
	"last_name"		=> "Last Name",
	"nickname"		=>	"Nickname",
	"aim"			=> "AIM",
	"yim"			=> "Yahoo IM",
	"jabber"		=>	"Jabber / Google Talk"
	);
	
$fergcorp_forceRegistrationField_getOptions = get_option("fergcorp_forceRegistrationField");

/**
 * Creates the administration panel
 *
 * @since 0.5
 * @access private
 * @author Andrew Ferguson
*/
function fergcorp_forceRegistrationField_myOptionsSubpanel(){
	global $fergcorp_forceRegistrationField_knownFields, $fergcorp_forceRegistrationField_getOptions;
	
	if (isset($_POST['info_update']))
	{
		$results = array(	"additionalFields" => $_POST['additionalFields']);
		update_option("fergcorp_forceRegistrationField", $results);

		echo '<div id="message" class="updated fade"><p>'. __('Options updated successfully.', 'fergcorp_forceRegistrationField') .'</p></div>';					//Report to the user that the data has been updated successfully
	}
	
	$fergcorp_forceRegistrationField_getOptions = get_option("fergcorp_forceRegistrationField");
?>
<div id="wpbody">
	<div class=wrap>
		<form method="post" name="fergcorp_forceRegistrationField">
            <h2><?php _e('Force Registration Field', 'fergcorp_forceRegistrationField'); ?></h2>
            <div id="poststuff">        
                <div class="stuffbox">
                    <h3><?php _e('Addition Fields', 'fergcorp_forceRegistrationField'); ?></h3>
                    <div class="inside">
                        
                        <p><?php _e('By default, Wordpress will only require an email address and username to register an account. Here, you can select additional fields required for registration.', 'fergcorp_forceRegistrationField'); ?></p>
    
                        <select name="additionalFields[]" id="fergcorpForceRegistrationFieldAdditionalFields" size="8" multiple style="height:100px">
                        <?php
                            foreach($fergcorp_forceRegistrationField_knownFields as $key => $value){
                                if(in_array("$key", $fergcorp_forceRegistrationField_getOptions["additionalFields"])){
                                    $selected = "selected=\"selected\"";
                                }
                                else{
                                    $selected = NULL;
                                }
                                echo "<option value=\"$key\" $selected >$value</option>\r\n";
                            }
                        ?>
                        </select>
    
                        <p><em><?php _e("Hold 'Ctrl' to select multiple options", 'fergcorp_forceRegistrationField'); ?></em></p>
                        <p>
                            <input type="button" name="selectNone" value="<?php _e('Select None', 'fergcorp_forceRegistrationField'); ?>" onClick="document.getElementById('fergcorpForceRegistrationFieldAdditionalFields').options.selectedIndex=-1;"/>
                        </p>					
                    </div>
                    <div class="submit"><input type="submit" name="info_update" value="<?php _e('Update options', 'fergcorp_forceRegistrationField'); ?>&raquo;" /></div>
                </div>
            </div>   
		</form>
	</div>
</div>
<?php
}

/**
 * Add fields to the new user registration page that the user must fill out to register
 *
 * @since 0.5
 * @access private
 * @author Andrew Ferguson
*/
function fergcorp_forceRegistrationField_addFields(){

	global $fergcorp_forceRegistrationField_knownFields, $fergcorp_forceRegistrationField_getOptions;

	if($fergcorp_forceRegistrationField_getOptions["additionalFields"]){
		foreach($fergcorp_forceRegistrationField_getOptions["additionalFields"] as $thisValue){
		?>
		<p>
			<label><?php _e($fergcorp_forceRegistrationField_knownFields[$thisValue], 'fergcorp_forceRegistrationField') ?><br />
			<input type="text" name="<?php echo $thisValue; ?>" id="<?php echo $thisValue; ?>" class="input" value="<?php echo attribute_escape(stripslashes($_POST[$thisValue])); ?>" size="25" tabindex="10" style="font-size: 20px; width: 97%;	padding: 3px; margin-right: 6px;" /></label>
		</p>
		<?php
		}
	}

}

/**
 * Checks registration fields to make sure they are filled out (although that is the extent of the checking). If they are not, an error is added to WP_Error
 *
 * @param $user_login don't care
 * @param $user_email don't care
 * @param $errors object WP_Error object that contains the list of existing registration errors, if any
 * @since 0.5
 * @access private
 * @author Andrew Ferguson
*/
function fergcorp_forceRegistrationField_checkFields($user_login, $user_email, $errors){

	global $fergcorp_forceRegistrationField_knownFields, $fergcorp_forceRegistrationField_getOptions;

	foreach($fergcorp_forceRegistrationField_getOptions["additionalFields"] as $thisValue){
		if ($_POST[$thisValue] == '') {
			$errors->add('empty_'.$thisValue , __("<strong>ERROR</strong>: Please type your ".$fergcorp_forceRegistrationField_knownFields[$thisValue].".",'fergcorp_forceRegistrationField'));
		}
	}
}

/**
 * Add the additional metadata into the database after the user is created
 *
 * @since 0.5
 * @access private
 * @author Andrew Ferguson
*/
function fergcorp_forceRegistrationField_updateFields($user_id){

	global $fergcorp_addField, $fergcorp_forceRegistrationField_getOptions;

	foreach($fergcorp_forceRegistrationField_getOptions["additionalFields"] as $thisValue){
		update_usermeta( $user_id, $thisValue, $_POST[$thisValue]);
	}

}

/**
 * Add the management page to the settings bar
 *
 * @since 0.5
 * @access private
 * @author Andrew Ferguson
*/
function fergcorp_forceRegistrationField_optionsPage(){
  if(function_exists('add_management_page')){
    	add_options_page('Force User Field Registration', 'Force User Field Registration', 10, basename(__FILE__), 'fergcorp_forceRegistrationField_myOptionsSubpanel');
		}
}
?>